@@ -39,23 +39,24 @@
 #include "ianjuta-iterable.h"
 #include "ianjuta-iterable-tree.h"
 #include "ianjuta-language.h"
-#include "ianjuta-language-support.h"
 #include "ianjuta-loader.h"
-#include "ianjuta-macro.h"
 #include "ianjuta-markable.h"
 #include "ianjuta-message-manager.h"
 #include "ianjuta-message-view.h"
 #include "ianjuta-plugin-factory.h"
 #include "ianjuta-preferences.h"
 #include "ianjuta-print.h"
+#include "ianjuta-project.h"
 #include "ianjuta-project-backend.h"
 #include "ianjuta-project-manager.h"
 #include "ianjuta-provider.h"
+#include "ianjuta-snippets-manager.h"
 #include "ianjuta-stream.h"
 #include "ianjuta-stream-loader.h"
 #include "ianjuta-stream-savable.h"
 #include "ianjuta-symbol.h"
 #include "ianjuta-symbol-manager.h"
+#include "ianjuta-symbol-query.h"
 #include "ianjuta-terminal.h"
 #include "ianjuta-todo.h"
 #include "ianjuta-vcs.h"
